package com.example.smmlb.Api

import Fragments.AnalizFragment
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import com.example.smmlb.databinding.ItemobjectBinding
import com.example.smmlb.R
import com.example.smmlb.model.CatalogApi

// Класс для отображения объектов в view
class AdapterCharacter(private val listener: AnalizFragment) :
// RecyclerView.Adapter универсальный элемент управления с большими возможностями
    RecyclerView.Adapter<AdapterCharacter.CharacterHolder>() {
    private val characterList = ArrayList<CatalogApi>()
    // ViewHolder описывает вид элемента и метаданные о его месте в RecyclerView
    class CharacterHolder(item: View) : RecyclerView.ViewHolder(item) {
        private val binding = ItemobjectBinding.bind(item) // Находим необходимый layout (шаблон)
        /**
        @param result - Один объект их списка
        @param listener - Слушатель объекта (дальше мы повесим на него клик)
         */
        fun bind(catalog: CatalogApi, listener: AnalizFragment) = with(binding)
        {
            // Расскладываем данные по объектам на странице Itemobject
            nameCharacter.text = catalog.name
            DayCharacter.text = catalog.timeResul
            price.text = catalog.price.toString()
        }
    }

    //Вызывается, когда RecyclerView требуется новый элемент ViewHolder данного типа для представления элемента
    /**
    @param parent- Группа просмотра, в которую будет добавлено новое представление после привязки к позиции адаптера
    @param viewType- Тип представления нового представления*/
    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): CharacterHolder {
        val view = LayoutInflater.from(parent.context).inflate(R.layout.itemobject, parent, false)
        /* В первом параметре указывается идентификатор ресурса разметки, в который мы собираемся добавлять объекты.
         Во втором параметре указывается корневой компонент, к которому нужно присоединить объекты.
         В третьем параметре (если он используется) указывается, нужно ли присоединять объекты к корневому элементу.*/
        return CharacterHolder(view)
    }
    //Вызывается RecyclerView для отображения данных в указанной позиции
    /**
    @param holder - ViewHolder, который должен быть обновлен для представления
    содержимого элемента в заданной позиции в наборе данных
    @param position - Положение элемента в наборе данных адаптера.
     */
    override fun onBindViewHolder(holder: CharacterHolder, position: Int) {
        holder.bind(characterList[position], listener)
    }
    //Возвращает стабильный идентификатор для элемента по адресу position.
    override fun getItemCount(): Int {
        return characterList.size
    }
    //Добавляем объект в лист и сохраняем изменения
    fun addResult(character: CatalogApi) {
        characterList.add(character)
        notifyDataSetChanged()
    }

    interface Listener {
        fun OnClick(result: CatalogApi)
    }}